#!/bin/sh
# Script for execution of deployed PhagoSight as a MATLAB standalone application. 
#
# Sets up the MCR environment for the current $ARCH and executes 
# the specified command. 
# 
# Requirements: Matlab Compiler Runtime (MCR) v8.1, JDK v1.7. 
# The MCR (8.1) is available at: http://uk.mathworks.com/products/compiler/mcr/
# It must be downloaded and installed on the machine.
# 
# USAGE:
# (1) ./run_PhagoSight.sh deployedMCRroot PATH/to/DATASET 0N
# 
# By default, the MCR is supposed to be at:
# /usr/local/MATLAB/MATLAB_Compiler_Runtime/v81
#
exe_name=$0
exe_dir=`dirname "$0"`
echo "------------------------------------------"
if [ "x$1" = "x" ]; then
    echo "Usage:"
    echo "   $0 \<deployedMCRroot\> PATH/to/DATASET 0N"
    echo ""
    echo "to use default MCR location: /usr/local/MATLAB/MATLAB_Compiler_Runtime/v81"
    echo "get the Matlab Compiler Runtime (v8.1) at "
    echo "http://uk.mathworks.com/products/compiler/mcr" 
    exit 1  
else
  echo Setting up environment variables
  MCRROOT="$1"
  LD_LIBRARY_PATH=.:${MCRROOT}/runtime/glnxa64 ;
  LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRROOT}/bin/glnxa64 ;
  LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRROOT}/sys/os/glnxa64;
	MCRJRE=${MCRROOT}/sys/java/jre/glnxa64/jre/lib/amd64 ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/native_threads ; 
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/server ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/client ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE} ;  
  XAPPLRESDIR=${MCRROOT}/X11/app-defaults ;
  export LD_LIBRARY_PATH;
  export XAPPLRESDIR;
  shift 1
  args=
  while [ $# -gt 0 ]; do
      token=$1
      args="${args} \"${token}\"" 
      shift
  done
  echo ---
  echo Welcome to PhagoSight! 
  echo "\"${exe_dir}/PhagoSight\"" $args
  eval "\"${exe_dir}/PhagoSight\"" $args
  echo ---
fi
exit

